# zero-pad.pl - zero-pad numbers at the start of file names

## Synopsis

    perl zero-pad.pl [-dehlt] [long options...]
    
# Description

Without zero padding the shell will list numbered files in the wrong
("alphabetical") order:
    
    $ ls
    042.html
    1.html
    108.html
    12.html
    5.html
    
If you run this script in the directory containing the files

    $ perl zero-pad.pl
    
a new directory `zero-padded` containing copies of the same files with
their names padded to the same length with `0` characters will be created.
The shell will list these in the right order:
    
    $ ls zero-padded
    001.html
    005.html
    012.html
    042.html
    108.html
    
You can use several options to customize the format of the padded
numbers, the names of the source and target directories and the extension of
the files. See [Options](#Options) below!
    
## Installation

This script requires perl >= 5.14

Before running the script for the first time run these commands:

    cpan install App::cpanminus
    cpanm Getopt::Long::Descriptive Path::Tiny
    
See

-   <https://learn.perl.org/installing/>
-   <https://www.cpan.org/modules/INSTALL.html>
    
## Options

	--length INT (or -l)      Number of digits to pad to.
	                          (default value: 3)
	Should be at least equal to the length of
	the longest number you already got.

	--extension STR (or -e)   File extension of files to rename.
	                          (default value: html)

	--dir STR (or -d)         Directory containing files.
	                          (default value: .)
	--target-dir STR (or -t)  Directory to put renamed files (copies).
	                          (default value: zero-padded)

	--format STR (or -f)      Custom sprintf format for padded numbers.
	Overrides --length. Useful to create e.g.
	"sparse" numbers: -f '%03d0'
	for 0080, 0090, 0100, 0110 instead of 008, 009, 010, 011           
	Note that -l 3 is equivalent to -f '%03d'!

	--help (or -h)            Print help text and exit.

## Warning

If the target directory/folder already exists any files inside it with matching
names ***will** be overwritten*! Always back up or use a new target directory
name!

## Author

Benct Philip Jonsson
<bpjonsson+zero-pad@gmail.com>
<https://github.com/bpj/>

## Copyright and license

This software is copyright (c) 2022 by Benct Philip Jonsson.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

http://dev.perl.org/licenses/

